CSets: Supplemental Unicode Mapping Tables
------------------------------------------

Provided on http://sofia.nmsu.edu/~mleisher/Software/csets/

> This archive is freeware.

> The CSets collection is a set of mapping tables between various character sets and Unicode, and
> is intended to provide mappings not included in most character set conversion
> tools available today. The origin of this distribution was several projects that involved text
> encoded in many obscure character encodings. Many of these encodings are not supported in the most
> frequently used character set conversion tools (i.e. iconv), so this package was put together to
> provide the encoding information in a simple, consistent format.
